@@ -47,9 +47,9 @@ epub_pre_files = [('index.xhtml', 'Welcome')]
 epub_post_files = [('usage/installation.xhtml', 'Installing Sphinx'),
                    ('develop.xhtml', 'Sphinx development')]
 epub_exclude_files = ['_static/opensearch.xml', '_static/doctools.js',
-                      '_static/jquery.js', '_static/searchtools.js',
+                      '_static/searchtools.js',
                       '_static/sphinx_highlight.js',
-                      '_static/underscore.js', '_static/basic.css',
+                      '_static/basic.css',
                       '_static/language_data.js',
                       'search.html', '_static/websupport.js']
 epub_fix_images = False
@@ -70,6 +70,7 @@ latex_elements = {
 \DeclareUnicodeCharacter{229E}{\ensuremath{\boxplus}}
 \setcounter{tocdepth}{3}%    depth of what main TOC shows (3=subsubsection)
 \setcounter{secnumdepth}{1}% depth of section numbering
+\setlength{\tymin}{2cm}%     avoid too cramped table columns
 ''',
     # fix missing index entry due to RTD doing only once pdflatex after makeindex
     'printindex': r'''
@@ -77,12 +78,6 @@ latex_elements = {
              {\footnotesize\raggedright\printindex}
              {\begin{sphinxtheindex}\end{sphinxtheindex}}
 ''',
-    'sphinxsetup': """%
-VerbatimColor={RGB}{242,242,242},%
-VerbatimBorderColor={RGB}{32,32,32},%
-pre_border-radius=3pt,%
-pre_box-decoration-break=slice,%
-""",
 }
 latex_show_urls = 'footnote'
 latex_use_xindy = True
@@ -129,7 +124,7 @@ gettext_compact = False
 
 # -- Extension interface -------------------------------------------------------
 
-from sphinx import addnodes  # noqa
+from sphinx import addnodes  # noqa: E402
 
 event_sig_re = re.compile(r'([a-zA-Z-]+)\s*\((.*)\)')
 
@@ -164,7 +159,7 @@ def linkify_issues_in_changelog(app, docname, source):
 
         def linkify(match):
             url = 'https://github.com/sphinx-doc/sphinx/issues/' + match[1]
-            return '`{} <{}>`_'.format(match[0], url)
+            return f'`{match[0]} <{url}>`_'
 
         linkified_changelog = re.sub(r'(?:PR)?#([0-9]+)\b', linkify, changelog)
 
@@ -187,6 +182,15 @@ def setup(app):
     app.add_object_type('event', 'event', 'pair: %s; event', parse_event,
                         doc_field_types=[fdesc])
 
+    # Load jQuery and patches to make readthedocs-doc-embed.js available (refs: #10574)
+    app.add_js_file('https://ajax.googleapis.com/ajax/libs/jquery/3.6.0/jquery.min.js',
+                    priority=100)
+    app.add_js_file(
+        'https://cdnjs.cloudflare.com/ajax/libs/underscore.js/1.13.1/underscore-min.js',
+        priority=100,
+    )
+    app.add_js_file('_sphinx_javascript_frameworks_compat.js', priority=105)
+
     # workaround for RTD
     from sphinx.util import logging
     logger = logging.getLogger(__name__)
